@@ -22,11 +22,10 @@ from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
 from ai.h2o.sparkling.ml.models.H2OGAMMOJOModel import H2OGAMMOJOModel
 from ai.h2o.sparkling.ml.params.H2OGAMParams import H2OGAMParams
-from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.FamilyBasedH2OTrainFramePreparation import FamilyBasedH2OTrainFramePreparation
 
 
-class H2OGAM(H2OGAMParams, H2OCommonParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OTrainFramePreparation):
+class H2OGAM(H2OGAMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OTrainFramePreparation):
 
     @keyword_only
     def __init__(self,
@@ -34,7 +33,9 @@ class H2OGAM(H2OGAMParams, H2OCommonParams, H2OSupervisedAlgorithmWithFoldColumn
                  betaConstraints=None,
                  gamCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -45,7 +46,6 @@ class H2OGAM(H2OGAMParams, H2OCommonParams, H2OSupervisedAlgorithmWithFoldColumn
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  seed=-1,
                  family="AUTO",
                  tweedieVariancePower=0.0,
@@ -79,6 +79,7 @@ class H2OGAM(H2OGAMParams, H2OCommonParams, H2OSupervisedAlgorithmWithFoldColumn
                  computePValues=False,
                  removeCollinearCols=False,
                  numKnots=None,
+                 splineOrders=None,
                  scale=None,
                  bs=None,
                  keepGamCols=False,
