@@ -32,6 +32,7 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -42,7 +43,6 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  ntrees=50,
                  maxDepth=6,
                  minRows=1.0,
