@@ -75,6 +75,12 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
         """Regularization strength""",
         H2OTypeConverters.toNullableListFloat())
 
+    startval = Param(
+        Params._dummy(),
+        "startval",
+        """double array to initialize coefficients for GAM.""",
+        H2OTypeConverters.toNullableListFloat())
+
     lambdaSearch = Param(
         Params._dummy(),
         "lambdaSearch",
@@ -219,16 +225,22 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
         """Number of knots for gam predictors""",
         H2OTypeConverters.toNullableListInt())
 
+    splineOrders = Param(
+        Params._dummy(),
+        "splineOrders",
+        """Order of I-splines used for gam predictors. If specified, must be the same size as gam_columns.Values for bs=0 or 1 will be ignored.""",
+        H2OTypeConverters.toNullableListInt())
+
     scale = Param(
         Params._dummy(),
         "scale",
-        """Smoothing parameter for gam predictors""",
+        """Smoothing parameter for gam predictors.  If specified, must be of the same length as gam_columns""",
         H2OTypeConverters.toNullableListFloat())
 
     bs = Param(
         Params._dummy(),
         "bs",
-        """Basis function type for each gam predictors, 0 for cr""",
+        """Basis function type for each gam predictors, 0 for cr, 1 for thin plate regression with knots, 2 for monotone splines.  If specified, must be the same size as gam_columns""",
         H2OTypeConverters.toNullableListInt())
 
     keepGamCols = Param(
@@ -237,10 +249,22 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
         """Save keys of model matrix""",
         H2OTypeConverters.toBoolean())
 
+    standardizeTpGamCols = Param(
+        Params._dummy(),
+        "standardizeTpGamCols",
+        """standardize tp (thin plate) predictor columns""",
+        H2OTypeConverters.toBoolean())
+
+    scaleTpPenaltyMat = Param(
+        Params._dummy(),
+        "scaleTpPenaltyMat",
+        """Scale penalty matrix for tp (thin plate) smoothers as in R""",
+        H2OTypeConverters.toBoolean())
+
     knotIds = Param(
         Params._dummy(),
         "knotIds",
-        """String arrays storing frame keys of knots.  One for each gam column specified in gam_columns""",
+        """Array storing frame keys of knots.  One for each gam column set specified in gam_columns""",
         H2OTypeConverters.toNullableListString())
 
     modelId = Param(
@@ -282,7 +306,7 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -351,6 +375,12 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
         """Automatically export generated models to this directory.""",
         H2OTypeConverters.toNullableString())
 
+    aucType = Param(
+        Params._dummy(),
+        "aucType",
+        """Set default multinomial AUC type.""",
+        H2OTypeConverters.toEnumString("hex.MultinomialAucType"))
+
     ##
     # Getters
     ##
@@ -378,6 +408,9 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def getLambdaValue(self):
         return self.getOrDefault(self.lambdaValue)
 
+    def getStartval(self):
+        return self.getOrDefault(self.startval)
+
     def getLambdaSearch(self):
         return self.getOrDefault(self.lambdaSearch)
 
@@ -450,6 +483,9 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def getNumKnots(self):
         return self.getOrDefault(self.numKnots)
 
+    def getSplineOrders(self):
+        return self.getOrDefault(self.splineOrders)
+
     def getScale(self):
         return self.getOrDefault(self.scale)
 
@@ -459,6 +495,12 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def getKeepGamCols(self):
         return self.getOrDefault(self.keepGamCols)
 
+    def getStandardizeTpGamCols(self):
+        return self.getOrDefault(self.standardizeTpGamCols)
+
+    def getScaleTpPenaltyMat(self):
+        return self.getOrDefault(self.scaleTpPenaltyMat)
+
     def getKnotIds(self):
         return self.getOrDefault(self.knotIds)
 
@@ -516,6 +558,9 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
+    def getAucType(self):
+        return self.getOrDefault(self.aucType)
+
     ##
     # Setters
     ##
@@ -543,6 +588,9 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def setLambdaValue(self, value):
         return self._set(lambdaValue=value)
 
+    def setStartval(self, value):
+        return self._set(startval=value)
+
     def setLambdaSearch(self, value):
         return self._set(lambdaSearch=value)
 
@@ -615,6 +663,9 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def setNumKnots(self, value):
         return self._set(numKnots=value)
 
+    def setSplineOrders(self, value):
+        return self._set(splineOrders=value)
+
     def setScale(self, value):
         return self._set(scale=value)
 
@@ -624,6 +675,12 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def setKeepGamCols(self, value):
         return self._set(keepGamCols=value)
 
+    def setStandardizeTpGamCols(self, value):
+        return self._set(standardizeTpGamCols=value)
+
+    def setScaleTpPenaltyMat(self, value):
+        return self._set(scaleTpPenaltyMat=value)
+
     def setKnotIds(self, value):
         return self._set(knotIds=value)
 
@@ -680,3 +737,6 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
+
+    def setAucType(self, value):
+        return self._set(aucType=value)
