@@ -63,6 +63,12 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
         """Bandwidth (sigma) of Gaussian multiplicative noise ~N(1,sigma) for tree node predictions""",
         H2OTypeConverters.toFloat())
 
+    interactionConstraints = Param(
+        Params._dummy(),
+        "interactionConstraints",
+        """A set of allowed column interactions.""",
+        H2OTypeConverters.toNullableListListString())
+
     balanceClasses = Param(
         Params._dummy(),
         "balanceClasses",
@@ -246,7 +252,7 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -360,6 +366,9 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
     def getPredNoiseBandwidth(self):
         return self.getOrDefault(self.predNoiseBandwidth)
 
+    def getInteractionConstraints(self):
+        return self.getOrDefault(self.interactionConstraints)
+
     def getBalanceClasses(self):
         return self.getOrDefault(self.balanceClasses)
 
@@ -519,6 +528,9 @@ class H2OGBMParams(HasMonotoneConstraints, HasCalibrationDataFrame, HasIgnoredCo
     def setPredNoiseBandwidth(self, value):
         return self._set(predNoiseBandwidth=value)
 
+    def setInteractionConstraints(self, value):
+        return self._set(interactionConstraints=value)
+
     def setBalanceClasses(self, value):
         return self._set(balanceClasses=value)
 
